@@ -12,7 +12,7 @@ Lingua::EN::Inflect::Phrase - Inflect short English Phrases
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -44,10 +44,6 @@ our @EXPORT_OK = qw/to_PL to_S/;
 
 =head1 SUBROUTINES
 
-=head2 to_PL
-
-Attempts to pluralizes a phrase unless already plural.
-
 =cut
 
 my $NOUN = qr{(\S+)/(NN|CD)};
@@ -97,6 +93,12 @@ sub _inflect {
   return $phrase;
 }
 
+=head2 to_PL
+
+Attempts to pluralizes a phrase unless already plural.
+
+=cut
+
 sub to_PL {
   return _inflect(shift, 1, \&Lingua::EN::Inflect::Number::to_PL);
 }
@@ -111,10 +113,6 @@ sub to_S {
   return _inflect(shift, 0, \&Lingua::EN::Inflect::Number::to_S);
 }
 
-=head1 AUTHOR
-
-Rafael Kitover, C<< <rkitover at cpan.org> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-lingua-en-inflect-phrase at
@@ -147,6 +145,18 @@ L<http://search.cpan.org/dist/Lingua-EN-Inflect-Phrase/>
 
 =back
 
+=head1 REPOSITORY
+
+  git clone git://github.com/rkitover/lingua-en-inflect-phrase.git lingua-en-inflect-phrase
+
+=head1 SEE ALSO
+
+L<Lingua::EN::Inflect>, L<Lingua::EN::Inflect::Number>, L<Lingua::EN::Tagger>
+
+=head1 AUTHOR
+
+Rafael Kitover <rkitover@cpan.org>
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (c) 2010 Rafael Kitover (rkitover@cpan.org).
